package com.bonus.sgzb.material.service;

import com.bonus.sgzb.base.api.domain.MaMachineLabel;
import com.bonus.sgzb.common.core.web.domain.AjaxResult;
import com.bonus.sgzb.material.domain.PurchaseMacodeInfo;
import com.bonus.sgzb.base.api.domain.MaInputVO;

import java.util.List;

/**
 * 新购验收编号管理purchase_macode_infoService接口
 * 
 * @author bonus
 * @date 2023-12-10
 */
public interface IPurchaseMacodeInfoService 
{
    /**
     * 查询新购验收编号管理purchase_macode_info
     * 
     * @param taskId 新购验收编号管理purchase_macode_info主键
     * @return 新购验收编号管理purchase_macode_info
     */
    public PurchaseMacodeInfo selectPurchaseMacodeInfoByTaskId(Long taskId);

    /**
     * 查询新购验收编号管理purchase_macode_info列表
     * 
     * @param purchaseMacodeInfo 新购验收编号管理purchase_macode_info
     * @return 新购验收编号管理purchase_macode_info集合
     */
    public List<PurchaseMacodeInfo> selectPurchaseMacodeInfoList(PurchaseMacodeInfo purchaseMacodeInfo);
    public List<PurchaseMacodeInfo> selectPurchaseMacodeInfoListDetails(PurchaseMacodeInfo purchaseMacodeInfo);

    /**
     * 新增新购验收编号管理purchase_macode_info
     * @param purchaseMacodeInfoList
     * @return
     * @throws Exception
     */
    public AjaxResult insertPurchaseMacodeInfo(List<PurchaseMacodeInfo> purchaseMacodeInfoList) throws Exception;

    /**
     * 修改新购验收编号管理purchase_macode_info
     * @param purchaseMacodeInfoList
     * @return
     * @throws Exception
     */
    public int updatePurchaseMacodeInfo(List<PurchaseMacodeInfo> purchaseMacodeInfoList) throws Exception;

    /**
     * 批量删除新购验收编号管理purchase_macode_info
     * 
     * @param taskIds 需要删除的新购验收编号管理purchase_macode_info主键集合
     * @return 结果
     */
    public int deletePurchaseMacodeInfoByTaskIds(Long[] taskIds);

    /**
     * 删除新购验收编号管理purchase_macode_info信息
     * 
     * @param taskId 新购验收编号管理purchase_macode_info主键
     * @return 结果
     */
    public int deletePurchaseMacodeInfoByTaskId(Long taskId);

    /**
     * 生成设备编号
     * @param maMachineLabel
     * @return
     */
    String generateEquipmentNumber(MaMachineLabel maMachineLabel);

    /**
     * 删除
     * @param id
     * @return
     */
    int deletePurchaseMacodeInfoById(Long id);
    /**
     * 新购入库审核  通过/不通过
     * @param maInputVO
     * @return
     */
    int modifyManageStatus(MaInputVO maInputVO) throws Exception;

    /**
     * 删除新购验收编号管理
     * @param maCode
     * @return
     */
    int deletePurchaseMacodeInfoByMaCode(String maCode);

    /**
     * 获取新购验收编号管理详细信息
     * @param purchaseMacodeInfo
     * @return
     */
    List<PurchaseMacodeInfo> selectPurchaseMacodeInfo(PurchaseMacodeInfo purchaseMacodeInfo);

    /**
     * 新购入库清单明细
     * @param purchaseMacodeInfo
     * @return
     */
    List<PurchaseMacodeInfo> selectPutinDetails(PurchaseMacodeInfo purchaseMacodeInfo);

    /**
    * 新购入库单
    * @param purchaseMacodeInfo
    * @return List<PurchaseMacodeInfo>
    */
    List<PurchaseMacodeInfo> warehousingEntry(PurchaseMacodeInfo purchaseMacodeInfo);
}
